@@ -54,7 +54,7 @@ exp_skip = DLStudio.SkipConnections( dl_studio = dls )
 #exp_skip.load_cifar_10_dataset_with_augmentation()
 exp_skip.load_cifar_10_dataset()
 
-model = exp_skip.BMEnet(skip_connections=False, depth=32)
+model = exp_skip.BMEnet(skip_connections=True, depth=32)
 
 dls.show_network_summary(model)
 
